'use strict';

var _cli = require('../../cli');

var _chalk = require('chalk');

var _chalk2 = _interopRequireDefault(_chalk);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

exports.command = 'add-user <email>';
exports.desc = 'Add user to account';
exports.builder = yargs => {
  yargs.positional('email', {
    description: 'Email of user to add',
    type: 'string'
  }).option('account-id', {
    description: 'Account id to add user to',
    alias: 'a',
    required: true
  });
};
exports.handler = argv => {
  _cli.SETTINGS.checkLogin();

  (0, _cli.addUserToAccount)(argv.accountId, argv.email, (response, body) => {
    if (response.statusCode === 201) {
      var _body$data = body.data;
      let email = _body$data.email,
          password = _body$data.password;

      _cli.LOGGER.info(_chalk2.default.green('User was created and added to account. Give them the following credentials to use:\n'));
      _cli.LOGGER.info(_chalk2.default.yellow(`  - Username: ${email}`));
      _cli.LOGGER.info(_chalk2.default.yellow(`  - Password: ${password}\n`));
      _cli.LOGGER.info('Once the user has logged in they may change their password with "cryptid user change-password"');
    } else if (response.statusCode === 200) {
      let email = body.data.email;

      _cli.LOGGER.info(_chalk2.default.yellow(`Existing user ${email} was successfully added to the account.`));
    } else if (response.statusCode === 400) {
      _cli.LOGGER.error(_chalk2.default.red(`The user ${argv.email} already has access to that account`));
      process.exit(1);
    } else if (response.statusCode === 404) {
      _cli.LOGGER.error(_chalk2.default.red('Account not found'));
      process.exit(1);
    } else if (response.statusCode === 403) {
      _cli.LOGGER.error(_chalk2.default.red('Invalid account'));
      process.exit(1);
    }
  });
};
//# sourceMappingURL=addUser.js.map