'use strict';

var _cli = require('../../cli');

var _easyTable = require('easy-table');

var _easyTable2 = _interopRequireDefault(_easyTable);

var _chalk = require('chalk');

var _chalk2 = _interopRequireDefault(_chalk);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

exports.command = 'create <product-name>';
exports.desc = 'Create a new product';
exports.builder = yargs => {
  yargs.positional('product-name', {
    desc: 'Name of the new product',
    type: 'string'
  }).option('account-id', {
    desc: 'Account ID to create product under',
    alias: 'a',
    type: 'number',
    required: true
  });
};
exports.handler = argv => {
  _cli.SETTINGS.checkLogin();

  let accountId = argv.accountId,
      productName = argv.productName;


  (0, _cli.createProduct)(accountId, productName, (response, body) => {
    if (response.statusCode === 201) {
      let t = new _easyTable2.default();

      let product = body.data;

      _cli.LOGGER.info(_chalk2.default.green(`Created product ${product.name}\n`));

      t.cell('ID', product.id);
      t.cell('Product Name', product.name);
      t.newRow();

      _cli.LOGGER.info(t.toString());
    } else {
      _cli.LOGGER.error(_chalk2.default.red('Error creating product'));
      process.exit(1);
    }
  });
};
//# sourceMappingURL=create.js.map