'use strict';

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _cli = require('../../cli');

var _easyTable = require('easy-table');

var _easyTable2 = _interopRequireDefault(_easyTable);

var _chalk = require('chalk');

var _chalk2 = _interopRequireDefault(_chalk);

var _lodash = require('lodash');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

exports.command = 'list';
exports.desc = 'List accessible products';
exports.builder = yargs => {
  yargs.option('account-id', {
    desc: 'Account ID to fetch products for',
    alias: 'a',
    type: 'number'
  });
};
exports.handler = argv => {
  _cli.SETTINGS.checkLogin();

  (0, _cli.fetchCurrentUser)((response, body) => {
    if (response.statusCode === 200) {
      let products = [];

      body.data.accounts.forEach(account => {
        account.products.forEach(product => {
          products.push(_extends({}, product, {
            accountId: account.id,
            accountName: account.name
          }));
        });
      });

      if (argv.accountId) {
        let accountId = parseInt(argv.accountId, 10);
        products = (0, _lodash.filter)(products, { accountId });
      }

      if (products.length === 0) {
        _cli.LOGGER.info(_chalk2.default.yellow('No matching properties found'));
        process.exit();
      }

      let t = new _easyTable2.default();

      products.forEach(product => {
        t.cell('ID', product.id);
        t.cell('Product Name', product.name);
        t.cell('Account Name (ID)', `${product.accountName} (${product.accountId})`);
        t.newRow();
      });

      t.sort(['Account Name (ID)', 'Product Name']);

      _cli.LOGGER.info(t.toString());
    } else {
      _cli.LOGGER.error(_chalk2.default.red('Error fetching products'));
      process.exit(1);
    }
  });
};
//# sourceMappingURL=list.js.map