'use strict';

var _cli = require('../../cli');

var _easyTable = require('easy-table');

var _easyTable2 = _interopRequireDefault(_easyTable);

var _chalk = require('chalk');

var _chalk2 = _interopRequireDefault(_chalk);

var _lodash = require('lodash');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

exports.command = 'create <property-name>';
exports.desc = 'Creates a new property';
exports.builder = yargs => {
  yargs.option('account-id', {
    desc: 'Account ID to create property under',
    alias: 'a',
    type: 'number',
    required: true
  }).option('product-id', {
    desc: 'Product ID to create property under',
    alias: 'p',
    type: 'number',
    required: true
  }).option('property-type', {
    desc: 'Type of property to create',
    choices: ['web', 'mobile'],
    required: true,
    alias: 't',
    type: 'string'
  });
};
exports.handler = argv => {
  _cli.SETTINGS.checkLogin();

  (0, _cli.createProperty)(argv, (response, body) => {
    if (response.statusCode === 201) {
      _cli.LOGGER.info(_chalk2.default.green('Property was created successfully'));
      let t = new _easyTable2.default();

      let property = body.data;

      t.cell('ID', property.id);
      t.cell('Property Name', property.name);
      t.cell('Type', (0, _lodash.head)(property.trackerId.split('|')));
      t.cell('Tracker ID', property.trackerId);
      t.newRow();

      _cli.LOGGER.info(t.toString());
    } else {
      _cli.LOGGER.error(_chalk2.default.red('Error creating property'));
      process.exit(1);
    }
  });
};
//# sourceMappingURL=create.js.map