'use strict';

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _cli = require('../../cli');

var _lodash = require('lodash');

var _easyTable = require('easy-table');

var _easyTable2 = _interopRequireDefault(_easyTable);

var _chalk = require('chalk');

var _chalk2 = _interopRequireDefault(_chalk);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

exports.command = 'list';
exports.desc = 'Lists accessible properties';
exports.builder = yargs => {
  yargs.option('account-id', {
    desc: 'Account ID to fetch properties for',
    alias: 'a',
    type: 'number'
  }).option('product-id', {
    desc: 'Product ID to fetch properties for',
    alias: 'p',
    type: 'number'
  });
};
exports.handler = argv => {
  _cli.SETTINGS.checkLogin();

  (0, _cli.fetchCurrentUser)((response, body) => {
    let properties = [];

    body.data.accounts.forEach(account => {
      account.products.forEach(product => {
        product.properties.forEach(property => {
          properties.push(_extends({}, property, {
            accountId: account.id,
            accountName: account.name,
            productId: product.id,
            productName: product.name
          }));
        });
      });
    });

    if (argv.accountId) {
      let accountId = parseInt(argv.accountId, 10);
      properties = (0, _lodash.filter)(properties, { accountId });
    }

    if (argv.productId) {
      let productId = parseInt(argv.productId, 10);
      properties = (0, _lodash.filter)(properties, { productId });
    }

    if (properties.length === 0) {
      _cli.LOGGER.info(_chalk2.default.yellow('No matching properties found'));
      process.exit();
    }

    let t = new _easyTable2.default();

    properties.forEach(property => {
      t.cell('ID', property.id);
      t.cell('Property Name', property.name);
      t.cell('Type', (0, _lodash.head)(property.trackerId.split('|')));
      t.cell('Tracker', property.trackerId);
      t.cell('Product (ID)', `${property.productName} (${property.productId})`);
      t.cell('Account (ID)', `${property.accountName} (${property.accountId})`);
      t.newRow();
    });

    t.sort(['Account (ID)', 'Product (ID)', 'Property Name']);

    _cli.LOGGER.info(t.toString());
  });
};
//# sourceMappingURL=list.js.map