'use strict';

var _cli = require('../../cli');

var _easyTable = require('easy-table');

var _easyTable2 = _interopRequireDefault(_easyTable);

var _chalk = require('chalk');

var _chalk2 = _interopRequireDefault(_chalk);

var _lodash = require('lodash');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

exports.command = 'update <property-name>';
exports.desc = 'Updates property';
exports.builder = yargs => {
  yargs.positional('property-name', {
    desc: 'New name of the property',
    type: 'string'
  }).option('account-id', {
    desc: 'Account ID of property to update',
    alias: 'a',
    type: 'number',
    required: true
  }).option('product-id', {
    desc: 'Product ID of property to update',
    alias: 'p',
    type: 'number',
    required: true
  }).option('property-id', {
    desc: 'Property ID of property to update',
    alias: 'r',
    type: 'number',
    required: true
  });
};
exports.handler = argv => {
  _cli.SETTINGS.checkLogin();

  (0, _cli.updateProperty)(argv, (response, body) => {
    if (response.statusCode === 200) {
      _cli.LOGGER.info(_chalk2.default.green('Property was updated successfully'));
      let t = new _easyTable2.default();

      let property = body.data;

      t.cell('ID', property.id);
      t.cell('Property Name', property.name);
      t.cell('Type', (0, _lodash.head)(property.trackerId.split('|')));
      t.cell('Tracker ID', property.trackerId);
      t.newRow();

      _cli.LOGGER.info(t.toString());
    } else {
      _cli.LOGGER.error(_chalk2.default.red('Error updating property'));
      process.exit(1);
    }
  });
};
//# sourceMappingURL=update.js.map