'use strict';

var _cli = require('../../cli');

var _chalk = require('chalk');

var _chalk2 = _interopRequireDefault(_chalk);

var _csvStringify = require('csv-stringify');

var _csvStringify2 = _interopRequireDefault(_csvStringify);

var _fs = require('fs');

var _fs2 = _interopRequireDefault(_fs);

var _graphqlTag = require('graphql-tag');

var _graphqlTag2 = _interopRequireDefault(_graphqlTag);

var _help = require('../../help');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

exports.command = 'run <graphql-file>';
exports.desc = 'Query the event store for a property';
exports.builder = yargs => {
  yargs.alias(['exec']).usage((0, _help.loadHelp)('cryptid-query-run')).positional('graphql-file', {
    description: 'Path to custom query document',
    type: 'string'
  }).option('format', {
    description: 'Results format (json or csv)',
    alias: 'f',
    choices: ['csv', 'json'],
    type: 'string',
    default: 'csv'
  });
};
exports.handler = argv => {
  _cli.SETTINGS.checkLogin();

  const client = (0, _cli.buildGQLClient)();
  let queryDocument = '';

  try {
    queryDocument = _fs2.default.readFileSync(argv.graphqlFile, 'utf8');
  } catch (err) {
    _cli.LOGGER.error(_chalk2.default.red(err.message));
    process.exit(1);
  }

  try {
    client.query({ query: (0, _graphqlTag2.default)(queryDocument) }).catch(err => _cli.LOGGER.error(_chalk2.default.red(err)) && process.exit(1)).then(resp => {

      switch (argv.format) {
        case 'json':
          _cli.LOGGER.info(JSON.stringify(resp.data));
          break;
        case 'csv':
        default:
          const opts = { header: true };
          if (resp.data.events) {
            const events = resp.data.events.map(event => {
              // eslint-disable-next-line no-unused-vars
              let __typename = event.__typename,
                  mappedEvent = _objectWithoutProperties(event, ['__typename']);

              return mappedEvent;
            });
            if (events.length > 0) {
              (0, _csvStringify2.default)(events, opts, (err, output) => {
                _cli.LOGGER.info(output);
              });
            }
          }

          const view = resp.data.view;
          if (view) {
            (0, _csvStringify2.default)(view.lines, opts, (err, output) => {
              _cli.LOGGER.info(`Event Summary: ${view.name}`);
              _cli.LOGGER.info('----------------------------------------------------');
              _cli.LOGGER.info(output);
            });
          }
          break;
      }
    });
  } catch (err) {
    _cli.LOGGER.error(_chalk2.default.red(err.message));
    process.emit(1);
  }
};
//# sourceMappingURL=run.js.map